@@ -64,7 +64,9 @@ class Worker(multiprocessing.Process):
 
         # Finish last task
         if self.processor:
-            self.processor.join()
+            while self.processor.is_alive():
+                with self.queue.lock:
+                    self.channel.connection.process_data_events()
 
         logger.debug("End run worker")
 
@@ -173,8 +175,9 @@ class Worker(multiprocessing.Process):
 
     def watch_load(self):
         while not self.shutdown_pending.is_set():
-            if self.is_load_high():
-                logger.warning('Load is high, pausing consume')
+            load = os.getloadavg()[0]
+            if load > self.config.MAX_LOAD:
+                logger.warning('Load is high (%s), pausing consume', load)
                 self.consumer.pause(10)
             sleep(1)
 
@@ -187,9 +190,6 @@ class Worker(multiprocessing.Process):
         logger.warning('Run time reached zero, cancelling consume.')
         self.shutdown()
 
-    def is_load_high(self):
-        return os.getloadavg()[0] > self.config.MAX_LOAD
-
     def register_signals(self):
         # SIGINT is ignored because when pressed Ctrl-C
         # SIGINT sent to both master and workers while.
